const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const replicacaoPage = require('../../../page-objects/parametrizacao/documentos fiscais/replicacaoDeDocumentos.po.js');
const j = require('../../../json/leitorJson.po.js');
const protractorHelper = require('protractor-helper');

const replicacaoGridId = '1637082955700653735653';
const documentosGeradosGridId = '1637082955257499122654';

const codigo = j.getValor('codigoReplicacao');

describe('Tela Replicação de documentos', () => {
	beforeEach(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		replicacaoPage.abrir();
		geral.searchAndClickGridField('NMFILIAL', j.getValor('unidade'), 'NMFILIAL');
		z.component.footer.clickRightActionByLabel('Filtrar', true);
	});

	afterEach(() => {
		geral.sair();
	});

	it('Deve acessar a tela Replicação de documentos', () => {
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${replicacaoGridId}`)));

		expect(z.component.header.getTitle())
			.toBe('Replicação de documentos');
	});

	it('Adicionar uma operação de replicação de documentos', () => {
		geral.clickAdicionar();
		replicacaoPage.adicionar(codigo, 'Entrada', j.getValor('tipoOperacao'),
			j.getValor('descricaoReplicacao'), 'Não');
		geral.clickSalvar();
		geral.filterIt(j.getValor('descricaoReplicacao'));
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${replicacaoGridId}`)));

		expect(geral.gridHasText(replicacaoGridId, codigo))
			.toBe(codigo);
		expect(geral.gridHasText(replicacaoGridId, j.getValor('descricaoReplicacao'), 3))
			.toBe(j.getValor('descricaoReplicacao'));
	});

	it('Adicionar um registro na aba Documentos Gerados', () => {
		geral.clickGrid('NRREPLICDOC', codigo, replicacaoGridId);
		geral.trocarAba('Documentos Gerados');
		geral.clickAdicionar();
		replicacaoPage.adicionarDocumentoGerado(j.getValor('unidade1'), j.getValor('unidade'),
			'Entrada', j.getValor('serie'), j.getValor('tipoOperacao'), j.getValor('descricaoReplicacao'));
		geral.clickSalvar();
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${documentosGeradosGridId}`)));

		expect(geral.gridHasText(documentosGeradosGridId, j.getValor('descricaoReplicacao'), 5))
			.toBe(j.getValor('descricaoReplicacao'));
	});

	it('Editar o registro adicionado no passo anterior', () => {
		geral.clickGrid('NRREPLICDOC', codigo, replicacaoGridId);
		geral.trocarAba('Documentos Gerados');
		geral.clickGrid('DSITREPLDOC', j.getValor('descricaoReplicacao'), documentosGeradosGridId);
		geral.clickEditar();
		replicacaoPage.editarDocumentoGerado(j.getValor('serie1'), j.getValor('descricaoReplicacao1'));
		geral.clickSalvar();
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${documentosGeradosGridId}`)));

		expect(geral.gridHasText(documentosGeradosGridId, j.getValor('descricaoReplicacao1'), 5))
			.toBe(j.getValor('descricaoReplicacao1'));
	});

	it('Excluir o registro da aba Documentos Gerados', () => {
		geral.clickGrid('NRREPLICDOC', codigo, replicacaoGridId);
		geral.trocarAba('Documentos Gerados');
		geral.clickGrid('DSITREPLDOC', j.getValor('descricaoReplicacao1'), documentosGeradosGridId);
		geral.clickExcluir();
		geral.clickSim();

		expect(geral.gridHasText(documentosGeradosGridId, j.getValor('descricaoReplicacao1'), 5))
			.toBeUndefined();
	});

	it('Editar registro adicionado no passo 2', () => {
		geral.clickGrid('NRREPLICDOC', codigo, replicacaoGridId);
		geral.clickEditar();
		replicacaoPage.editar(j.getValor('descricaoReplicacao1'), 'Sim');
		geral.clickSalvar();
		protractorHelper.waitForElementVisibility(element(by.id(`grid-${replicacaoGridId}`)));

		expect(geral.gridHasText(replicacaoGridId, j.getValor('descricaoReplicacao1'), 3))
			.toBe(j.getValor('descricaoReplicacao1'));
	});

	it('Excluir registro editado no passo anterior', () => {
		geral.clickGrid('NRREPLICDOC', codigo, replicacaoGridId);
		geral.clickExcluir();
		geral.clickSim();

		expect(geral.gridHasText(replicacaoGridId, codigo))
			.toBeUndefined();
		expect(geral.gridHasText(replicacaoGridId, j.getValor('descricaoReplicacao'), 3))
			.toBeUndefined();
	});
});
